==========================================
A Guide to creating a Risk Assessment tool
==========================================


1. Introduction
===============

Your goal is to create the content of the OiRA tool for enterprises in your sector, and to offer this sector-specific tool to them.
The OiRA tool promotes a stepwise approach to risk assessment and is made up of 5 steps:

  * **Preparation** > the sector introduces the end-users (enterprises) to the risk assessment

  * **Identification** > the end-user goes through the hazards/problems and answers YES or NO
 
  * **Evaluation** > the end-user evaluates the risks for each problem/hazard spotted

  * **Action plan** > the end-user fills in an action plan with measures to tackle all stated risks	

  * **Report** > the action plan becomes a report to be downloaded and printed

1.1 Keep in mind your end-user
------------------------------

It is important to **keep in mind your end-user: the micro and small sized enterprise (employer and worker(s)) and the structure** of the risk assessment tool should be as relevant as possible to the daily activities of the enterprises; the end-user thinks and acts in terms of his own business processes.
Often, the expert’s way of thinking differs from the practice of the end-user. The latter thinks in terms of his own work processes and uses his own language. Some examples:

  * the expert thinks of physical workload; *the end-user of physical work*

  * the expert thinks of the thermal environment; *the end-user of working in the heat/in the cold*

  * the expert thinks of safety and creates a module containing everything in that area; *the end-user may think of opening and closing a shop, for example, and what that involves, or dealing with aggressive customers and what to do about them.* 

1.2 Use easy language
---------------------

**Structuring the content of the risk assessment tool so that it is in line with the way the average end-user thinks and acts** makes the content recognisable, and it makes it easier to carry out an action plan to tackle the risks with feasible measures.
  
Another decisive aspect is the language used. The **language** should be easy to understand with no need for interpretation, referring to things by names that are familiar and usual to enterprises.

Short sentences (at best no longer than ten words) and clear everyday language that can be easily read by the layman will prevent the end-user from developing an aversion, and enable him to draw up an assessment and use the OiRA tool properly.

At the beginning of the tool you will be given the chance to write a short introductory text sending a positive **and encouraging message** regarding:

  * the **importance** of risk assessment

  * the fact that risk assessment is **not necessarily complicated** (the idea is to contribute to demystify risk assessment)

  * the fact that the tool has especially been conceived to **meet the needs of the enterprises** in the sector 


It is important that the text is not too long; otherwise it could discourage the end-user from using the tool.

2.Team
======

Although it is important to keep the project team manageable in terms of size, it should preferably consist of:

  * representative(s) of the trade association(s)

  * representative(s) of the trade union(s)

  * the OiRA developer
 
  * an expert in occupational safety and health  (with knowledge of and affinity with the sector)

  * end-users (e.g. management or staff from companies, trade unions officials, etc.)
 

3. Structure
============ 

3.1 Structure the content hierarchically
----------------------------------------

Before you start creating an OiRA tool, we recommend considering the number of matters which you want to address. Thorough consideration of the structure will pay dividends later on, so classify the subjects in a way that is relevant to end-users. 


The system offers a way to group topics, subtopics and types of risks together. The main goal of this grouping is to make it easier/more logical for the end-user to complete the risk assessment tool. Your risk assessment tool will therefore consist of:
 
 
.. image:: images/creation/module.png 
  :align: left
  :height: 32 px
  
**MODULES** = subjects  (locations, activities, …)
  
  *Example*: 
    Module 1: *Hair Shampooing*  (hairdresser sector)
  
  .. image:: images/creation/submodule.png 
    :align: left
    :height: 32 px
    
  **SUB-MODULES** (not compulsory) = sub-subjects
  
    *Example*: 
      Sub-module 1: *Working posture*
      
      Sub-module 2: *Contact with water and cosmetic products*
    
    .. image:: images/creation/risk.png 
      :align: left
      :height: 32 px
      
    **RISKS** = statements about a situation which is in order
    
      *Example*: 
        *1.1 The shampoo station is adjustable*
        
        *2.1 Suitable protective equipment, such as disposable safety gloves, is purchased*
      
      .. image:: images/creation/solution.png 
        :align: left
        :height: 32 px
        
      **SOLUTIONS** = preventive measures to solve the problem recommended by the expert
      
        *Example*: 
          *1.1 Taking regular breaks to be able to recover from physical work*

          *2.1 Using dust-free products*


The system also offers the possibility to:

  * skip one/a whole set of modules in case the content does not apply to the company activity

  * repeat some modules in the case of enterprises having multiple locations.

3.2 Think about the risk as an affirmative statement
--------------------------------------------------------------

Once you have decided about the main structure of the risk assessment tool you can start to identify and explain the various risks.
 
The system works with **affirmative statements**; that is, it states **whether a situation is ‘in order’ (the goal to be attained) or ‘not in order’;**
 
 .. note::

   Example: Good lighting is present.

The end-user answer is either a clear ‘yes’ or ‘no’. If the end-user answers with NO (= the situation is not in order), then the problem is automatically included in the action plan step and the end-user will have to propose a measure to tackle the risk.

3.3 Consider the different types of risks
-----------------------------------------

You can choose from 3 types of risks:

  * priority risk: refers to a risk considered by the sector to be among the high risks in the sector. 

    .. note::
    
      Example: Working at height in the construction sector: the scaffold is erected on a firm foundation


  * risk: refers to existing risks at the workplace or linked to the work carried out.

    .. note::

      Example: All office chairs are adjustable

To identify and evaluate the above two types of risk it is often necessary to examine the workplace (to walk around the workplace and look at what could cause harm; consult workers,  …).

 * policy: refers to agreements, procedures, and management decisions regarding OSH issues. 

   .. note::

     Example: Manufacturers are regularly asked about alternative safe products 

These policy statements can be answered from behind a desk (no need to examine the workplace).
 

3.4 Pre-set evaluation for the risk
-----------------------------------
 
For each “risk” type you can choose from 2 evaluation methods:

  * **Estimated**: by selecting from **high, medium** or **low**. 

  * **Calculated**: by evaluating the **probability, frequency** and **severity** separately. The OiRA tool will then automatically calculate the priority.

End-users will not have to evaluate the following risks in the “Evaluation” step:

  * Priority risks (considered by default as "high priority" and displayed as “high” in the action plan)

  * Policy (strictly speaking this is not a risk).


3.5 Propose solutions
---------------------

The sector is generally well-informed of the risks that are most likely to lead to occupational accidents and diseases. In order to help the end-user to find solutions to these risks, you can include the solutions recommended by the sector/experts.  While working on the action plan, the end-user will have the possibility to select the solutions and rework them (modify the text) according to the situation that prevails in their enterprise.

.. note::

  All the necessary documents are available on the OiRA community site http://www.oira.osha.europa.eu/documentation
